Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(274)

Unified Diff: pkg/front_end/lib/incremental_kernel_generator.dart

Issue 2864243004: Revert "Start using FileState/FileSystemState to provide consistent view." (Closed)
Patch Set: Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/front_end/lib/src/incremental/file_state.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/front_end/lib/incremental_kernel_generator.dart
diff --git a/pkg/front_end/lib/incremental_kernel_generator.dart b/pkg/front_end/lib/incremental_kernel_generator.dart
index f842f9fd9ab68b09fa2f61667ffa667c2849869f..f1094f1e46d937e456c20fa20fde8b22d42edd3c 100644
--- a/pkg/front_end/lib/incremental_kernel_generator.dart
+++ b/pkg/front_end/lib/incremental_kernel_generator.dart
@@ -95,10 +95,12 @@ abstract class IncrementalKernelGenerator {
/// errors, it is safe to call [computeDelta] again.
Future<DeltaProgram> computeDelta({Future<Null> watch(Uri uri, bool used)});
/// Remove the file associated with the given file [uri] from the set of
/// valid files. This guarantees that those files will be re-read on the
/// next call to [computeDelta]).
- void invalidate(Uri uri);
+ ///
+ /// TODO(scheglov) Update to use URI.
+ void invalidate(String path);
/// Remove all source files from the set of valid sources. This guarantees
/// that all files will be re-read on the next call to [computeDelta].
« no previous file with comments | « no previous file | pkg/front_end/lib/src/incremental/file_state.dart » ('j') | no next file with comments »
@@ -95,10 +95,12 @@ abstract class IncrementalKernelGenerator {
/// errors, it is safe to call [computeDelta] again.
Future<DeltaProgram> computeDelta({Future<Null> watch(Uri uri, bool used)});
- /// Remove the file associated with the given file [uri] from the set of
- /// valid files. This guarantees that those files will be re-read on the
+ /// Remove any source file(s) associated with the given file path from the set
+ /// of valid sources. This guarantees that those files will be re-read on the
/// next call to [computeDelta]).

Powered by Google App Engine
This is Rietveld 408576698